@@ -1,7 +1,7 @@
 from sqlalchemy import (
     Column,
     Integer,
-    Text,
+    Unicode,
     )
 
 from . import DBSession, Base
@@ -9,7 +9,7 @@ from . import DBSession, Base
 class Post(Base):
     __tablename__ = 'posts'
     id = Column(Integer, primary_key=True)
-    title = Column(Text, unique=True)
+    title = Column(Unicode(200), unique=True)
     content = Column(Text)
 
     def __init__(self, title, content):
